from dataclasses import dataclass

from dataclasses_json import dataclass_json

from milla_tdf.data_model.abstract import AbstractDataModel, AbstractMetaData

@dataclass
class StockPriceMetaData(AbstractMetaData):
    symbols: list[str]
    updated: list[str]
  

@dataclass
class StockPriceData(AbstractDataModel):
    Symbol:str
    Time: str
    Open: float
    High: float
    Low: float
    Close: float
    Volume: float



from dataclasses import dataclass

from dataclasses_json import dataclass_json

@dataclass_json
@dataclass
class AbstractDataModel:
    pass

@dataclass_json
@dataclass
class AbstractMetaData:
    pass



import pandas as pd
from milla_tdf.data_model.abstract import AbstractDataModel, AbstractMetaData


class AbstractStorage:
    @classmethod
    def load_config(cls, **kwargs):
        pass

    @classmethod
    def load_data(cls, data_model: AbstractDataModel, **kwargs) -> pd.DataFrame:
        pass

    @classmethod
    def load_metadata(cls,data_model: AbstractDataModel, **kwargs) -> AbstractMetaData:
        pass



import logging

from milla_tdf.config import TradingFrameWorkConfig


def initLoad():
    
    logging.getLogger('selenium').setLevel('ERROR')
    logging.getLogger('urllib3').setLevel('ERROR')
    logging.basicConfig(
        level=TradingFrameWorkConfig.log_level, format='[%(asctime)s] {%(pathname)s:%(lineno)d} %(levelname)s - %(message)s')

    logging.addLevelName(
        logging.INFO, "\033[1;36m%s\033[1;0m" % logging.getLevelName(logging.INFO))

    logging.addLevelName(
        logging.WARNING, "\033[1;31m%s\033[1;0m" % logging.getLevelName(logging.WARNING))

    logging.addLevelName(
        logging.ERROR, "\033[1;41m%s\033[1;0m" % logging.getLevelName(logging.ERROR))
